@@ -44,6 +44,9 @@ class CoinHistoryType(Enum):
     COIN_SEND = "COIN_SEND"
     COIN_RECV = "COIN_RECV"
     USED_VOUCHER_REDEEM = "USED_VOUCHER_REDEEM"
+    CAMPAIGN_REWARD = "CAMPAIGN_REWARD"
+    COIN_ADDED_BY_ADMIN = "COIN_ADDED_BY_ADMIN"
+    COIN_DELETED_BY_ADMIN = "COIN_DELETED_BY_ADMIN"
     UNKNOWN__ = "UNKNOWN__"
 
 
